@@ -21,7 +21,7 @@
     of any functions that are added.
 """
 
-__version__ = "2021.06.30"
+__version__ = "2021.11.16"
 
 import datetime as dt
 import json
@@ -34,7 +34,7 @@ class EzTDXException(Exception):
     pass
 
 class EzTDX():
-    def __init__(self, beid: str, web_services_key: str, app_id: int, sandbox: bool = True) -> None:
+    def __init__(self, api_url: str, beid: str, web_services_key: str, app_id: int, sandbox: bool = True) -> None:
         """ initialization """ 
         self.beid = beid
         self.web_services_key = web_services_key
@@ -44,8 +44,8 @@ class EzTDX():
         self.session = Session()
         self.credentials = {'BEID': self.beid, 'WebServicesKey': self.web_services_key}
 
-        self.sandbox_base_url = 'https://api.teamdynamix.com/SBTDWebApi/api'
-        self.prod_base_url = 'https://api.teamdynamix.com/TDWebApi/api'
+        self.sandbox_base_url = f'{api_url}/SBTDWebApi/api'
+        self.prod_base_url = f'{api_url}/TDWebApi/api'
         self.sandbox = sandbox
 
         if self.sandbox:
@@ -123,6 +123,13 @@ class EzTDX():
         except Exception as ex:
             self.log(f'Error in get_group_members: {ex}')
 
+    def get_location_by_id(self, location_id: int) -> dict:
+        """Get Location by ID"""
+        try:
+            return self._get_data(f'/locations/{location_id}')
+        except Exception as ex:
+            self.log(f'Error in get_location_by_id: {ex}')
+
     def get_person(self, user_id: str) -> Any:
         """Get User by ID"""
         try:
